pub struct ImageFormatCapability(/* private fields */);Expand description
Capabilities of an ImageFormat implementation.
Note that DECODE capability is omitted because the view-process can always decode formats.
Implementations
Sourceimpl ImageFormatCapability
impl ImageFormatCapability
Sourcepub const ENCODE: ImageFormatCapability
pub const ENCODE: ImageFormatCapability
View-process can encode images in this format.
Sourcepub const DECODE_ENTRIES: ImageFormatCapability
pub const DECODE_ENTRIES: ImageFormatCapability
View-process can decode multiple containers of the format with multiple image entries.
Sourcepub const ENCODE_ENTRIES: ImageFormatCapability
pub const ENCODE_ENTRIES: ImageFormatCapability
View-process can encode multiple images into a single container of the format.
Sourcepub const DECODE_PROGRESSIVE: ImageFormatCapability
pub const DECODE_PROGRESSIVE: ImageFormatCapability
View-process can decode pixels as they are received.
Note that the view-process can always handle progressive data by accumulating it and then decoding. The decoder can also decode the metadata before receiving all data, that does not count as progressive decoding either.
Sourceimpl ImageFormatCapability
impl ImageFormatCapability
Sourcepub const fn empty() -> ImageFormatCapability
pub const fn empty() -> ImageFormatCapability
Get a flags value with all bits unset.
Sourcepub const fn all() -> ImageFormatCapability
pub const fn all() -> ImageFormatCapability
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<ImageFormatCapability>
pub const fn from_bits(bits: u32) -> Option<ImageFormatCapability>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> ImageFormatCapability
pub const fn from_bits_truncate(bits: u32) -> ImageFormatCapability
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> ImageFormatCapability
pub const fn from_bits_retain(bits: u32) -> ImageFormatCapability
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<ImageFormatCapability>
pub fn from_name(name: &str) -> Option<ImageFormatCapability>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: ImageFormatCapability) -> bool
pub const fn intersects(&self, other: ImageFormatCapability) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: ImageFormatCapability) -> bool
pub const fn contains(&self, other: ImageFormatCapability) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn insert(&mut self, other: ImageFormatCapability)
pub fn insert(&mut self, other: ImageFormatCapability)
The bitwise or (|) of the bits in two flags values.
Sourcepub fn remove(&mut self, other: ImageFormatCapability)
pub fn remove(&mut self, other: ImageFormatCapability)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: ImageFormatCapability)
pub fn toggle(&mut self, other: ImageFormatCapability)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: ImageFormatCapability, value: bool)
pub fn set(&mut self, other: ImageFormatCapability, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(
self,
other: ImageFormatCapability,
) -> ImageFormatCapability
pub const fn intersection( self, other: ImageFormatCapability, ) -> ImageFormatCapability
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: ImageFormatCapability) -> ImageFormatCapability
pub const fn union(self, other: ImageFormatCapability) -> ImageFormatCapability
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(
self,
other: ImageFormatCapability,
) -> ImageFormatCapability
pub const fn difference( self, other: ImageFormatCapability, ) -> ImageFormatCapability
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(
self,
other: ImageFormatCapability,
) -> ImageFormatCapability
pub const fn symmetric_difference( self, other: ImageFormatCapability, ) -> ImageFormatCapability
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> ImageFormatCapability
pub const fn complement(self) -> ImageFormatCapability
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl ImageFormatCapability
impl ImageFormatCapability
Sourcepub const fn iter(&self) -> Iter<ImageFormatCapability>
pub const fn iter(&self) -> Iter<ImageFormatCapability>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<ImageFormatCapability>
pub const fn iter_names(&self) -> IterNames<ImageFormatCapability>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.